# Metrics

GAICo provides several metric classes for text evaluation. All metrics inherit from `BaseMetric`.

To make a custom metric, you can create a new class that inherits from `BaseMetric` and implements the `calculate()` method.

To view the documentation for a specific metric, you can click on the metric name in the table of contents on the left.
